@@ -4,7 +4,8 @@ import numpy as np
 
 from autoarray import exc
 from autoarray.mask import abstract_mask
-from autoarray.util import array_util
+from autoarray.structures import grids
+from autoarray.util import array_util, grid_util
 
 logging.basicConfig()
 logger = logging.getLogger(__name__)
@@ -60,6 +61,43 @@ class AbstractMask1d(abstract_mask.AbstractMask):
         else:
             self.origin = (0.0,)
 
+    @property
+    def mask_sub_1(self):
+        """
+        Returns the mask on the same scaled coordinate system but with a sub-grid of ``sub_size`` `.
+        """
+        return Mask1D(
+            mask=self, sub_size=1, pixel_scales=self.pixel_scales, origin=self.origin
+        )
+
+    @property
+    def unmasked_mask(self):
+        """The indicies of the mask's border pixels, where a border pixel is any unmasked pixel on an
+        exterior edge (e.g. next to at least one pixel with a `True` value but not central pixels like those within \
+        an annulus mask).
+        """
+        return Mask1D.unmasked(
+            shape_slim=self.shape_slim,
+            sub_size=self.sub_size,
+            pixel_scales=self.pixel_scales,
+            origin=self.origin,
+        )
+
+    @property
+    def unmasked_grid_sub_1(self):
+        """ The scaled-grid of (y,x) coordinates of every pixel.
+
+        This is defined from the top-left corner, such that the first pixel at location [0, 0] will have a negative x \
+        value y value in scaled units.
+        """
+        grid_slim = grid_util.grid_1d_via_mask_from(
+            mask_1d=self, pixel_scales=self.pixel_scales, sub_size=1, origin=self.origin
+        )
+
+        return grids.Grid2D(
+            grid=grid_slim, mask=self.unmasked_mask.mask_sub_1, store_slim=True
+        )
+
     def output_to_fits(self, file_path: str, overwrite: bool = False):
         """
         Write the 1D mask to a .fits file.
@@ -107,7 +145,9 @@ class Mask1D(AbstractMask1d):
         )
 
     @classmethod
-    def unmasked(cls, shape_1d, pixel_scales, sub_size=1, origin=(0.0,), invert=False):
+    def unmasked(
+        cls, shape_slim, pixel_scales, sub_size=1, origin=(0.0,), invert=False
+    ):
         """Setup a mask where all pixels are unmasked.
 
         Parameters
@@ -118,7 +158,7 @@ class Mask1D(AbstractMask1d):
             The scaled units to pixel units conversion factor of each pixel.
         """
         return cls.manual(
-            mask=np.full(shape=shape_1d, fill_value=False),
+            mask=np.full(shape=shape_slim, fill_value=False),
             pixel_scales=pixel_scales,
             origin=origin,
             sub_size=sub_size,
@@ -161,23 +201,23 @@ class Mask1D(AbstractMask1d):
 
     @property
     def is_all_false(self):
-        return self.pixels_in_mask == self.shape_1d
+        return self.pixels_in_mask == self.shape_slim
 
     @property
-    def shape_1d(self):
+    def shape_slim(self):
         return self.shape[0]
 
     @property
-    def shape_1d_scaled(self):
-        return float(self.pixel_scales * self.shape_1d)
+    def shape_slim_scaled(self):
+        return float(self.pixel_scales * self.shape_slim)
 
     @property
     def scaled_maxima(self):
-        return (self.shape_1d_scaled / 2.0) + self.origin
+        return (self.shape_slim_scaled / 2.0) + self.origin
 
     @property
     def scaled_minima(self):
-        return -(self.shape_1d_scaled / 2.0) + self.origin
+        return -(self.shape_slim_scaled / 2.0) + self.origin
 
     @property
     def extent(self):
