@@ -10,14 +10,11 @@ class AbstractStructure(np.ndarray):
             if hasattr(obj, "mask"):
                 self.mask = obj.mask
 
-            if hasattr(obj, "store_in_1d"):
-                self.store_in_1d = obj.store_in_1d
+    def _new_structure(self, grid, mask, store_slim):
+        """Conveninence method for creating a new instance of the Grid2D class from this grid.
 
-    def _new_structure(self, grid, mask, store_in_1d):
-        """Conveninence method for creating a new instance of the Grid class from this grid.
-
-        This method is over-written by other grids (e.g. GridIterate) such that the in_1d and in_2d methods return
-        instances of that Grid's type.
+        This method is over-written by other grids (e.g. Grid2DIterate) such that the slim and native methods return
+        instances of that Grid2D's type.
 
         Parameters
         ----------
@@ -26,27 +23,27 @@ class AbstractStructure(np.ndarray):
         mask : msk.Mask2D
             The 2D mask associated with the grid, defining the pixels each grid coordinate is paired with and
             originates from.
-        store_in_1d : bool
+        store_slim : bool
             If True, the grid is stored in 1D as an ndarray of shape [total_unmasked_pixels, 2]. If False, it is
             stored in 2D as an ndarray of shape [total_y_pixels, total_x_pixels, 2].
         """
         raise NotImplementedError()
 
     @property
-    def shape_1d(self):
-        return self.mask.shape_1d
+    def slim(self):
+        raise NotImplementedError
 
     @property
-    def sub_shape_1d(self):
-        return self.mask.sub_shape_1d
+    def native(self):
+        raise NotImplementedError
 
     @property
-    def shape_2d(self):
-        return self.mask.shape
+    def shape_slim(self):
+        return self.mask.shape_slim
 
     @property
-    def sub_shape_2d(self):
-        return self.mask.sub_shape_2d
+    def sub_shape_slim(self):
+        return self.mask.sub_shape_slim
 
     @property
     def pixel_scales(self):
@@ -64,17 +61,9 @@ class AbstractStructure(np.ndarray):
     def sub_size(self):
         return self.mask.sub_size
 
-    @property
-    def regions(self):
-        return self.mask.regions
-
-    @property
-    def geometry(self):
-        return self.mask.geometry
-
     @property
     def unmasked_grid(self):
-        return self.mask.geometry.unmasked_grid_sub_1
+        return self.mask.unmasked_grid_sub_1
 
     @property
     def total_pixels(self):
@@ -110,3 +99,31 @@ class AbstractStructure(np.ndarray):
 
     def output_to_fits(self, file_path, overwrite):
         raise NotImplementedError
+
+
+class AbstractStructure1D(AbstractStructure):
+
+    pass
+
+
+class AbstractStructure2D(AbstractStructure):
+    def __array_finalize__(self, obj):
+
+        super().__array_finalize__(obj=obj)
+
+        if isinstance(obj, AbstractStructure2D):
+
+            if hasattr(obj, "store_slim"):
+                self.store_slim = obj.store_slim
+
+    @property
+    def native(self):
+        raise NotImplementedError
+
+    @property
+    def shape_native(self):
+        return self.mask.shape
+
+    @property
+    def sub_shape_native(self):
+        return self.mask.sub_shape_native
