@@ -12,13 +12,13 @@ logging.basicConfig()
 logger = logging.getLogger(__name__)
 
 
-class Array(abstract_array.AbstractArray):
+class Array2D(abstract_array.AbstractArray2D):
     def __new__(
         cls,
         array,
         mask,
         exposure_info=None,
-        store_in_1d=True,
+        store_slim=True,
         zoom_for_plot=True,
         *args,
         **kwargs
@@ -26,15 +26,15 @@ class Array(abstract_array.AbstractArray):
         """An array of values, which are paired to a uniform 2D mask of pixels and sub-pixels. Each entry
         on the array corresponds to a value at the centre of a sub-pixel in an unmasked pixel.
 
-        An *Array* is ordered such that pixels begin from the top-row of the corresponding mask and go right and down.
+        An *Array2D* is ordered such that pixels begin from the top-row of the corresponding mask and go right and down.
         The positive y-axis is upwards and positive x-axis to the right.
 
         The array can be stored in 1D or 2D, as detailed below.
 
-        Case 1: [sub-size=1, store_in_1d = True]:
+        Case 1: [sub-size=1, store_slim = True]:
         -----------------------------------------
 
-        The Array is an ndarray of shape [total_unmasked_pixels].
+        The Array2D is an ndarray of shape [total_unmasked_pixels].
 
         The first element of the ndarray corresponds to the pixel index, for example:
 
@@ -73,7 +73,7 @@ class Array(abstract_array.AbstractArray):
         IxIxIxIxIxIxIxIxIxIxI \/   array[8] = 8
         IxIxIxIxIxIxIxIxIxIxI      array[9] = 9
 
-        Case 2: [sub-size>1, store_in_1d=True]:
+        Case 2: [sub-size>1, store_slim=True]:
         ------------------
 
         If the masks's sub size is > 1, the array is defined as a sub-array where each entry corresponds to the values
@@ -142,10 +142,10 @@ class Array(abstract_array.AbstractArray):
                  array[7] = value of first sub-pixel in pixel 7.
                  array[8] = value of first sub-pixel in pixel 8.
 
-        Case 3: [sub_size=1 store_in_1d=False]
+        Case 3: [sub_size=1 store_slim=False]
         --------------------------------------
 
-        The Array has the same properties as Case 1, but is stored as an an ndarray of shape
+        The Array2D has the same properties as Case 1, but is stored as an an ndarray of shape
         [total_y_values, total_x_values].
 
         All masked entries on the array have values of 0.0.
@@ -170,7 +170,7 @@ class Array(abstract_array.AbstractArray):
         - array[3,4] = 0
         - array[3,4] = -1
 
-        Case 4: [sub_size>1 store_in_1d=False]
+        Case 4: [sub_size>1 store_slim=False]
         --------------------------------------
 
         The properties of this array can be derived by combining Case's 2 and 3 above, whereby the array is stored as
@@ -185,7 +185,7 @@ class Array(abstract_array.AbstractArray):
         mask : msk.Mask2D
             The 2D mask associated with the array, defining the pixels each array value is paired with and
             originates from.
-        store_in_1d : bool
+        store_slim : bool
             If True, the array is stored in 1D as an ndarray of shape [total_unmasked_pixels]. If False, it is
             stored in 2D as an ndarray of shape [total_y_pixels, total_x_pixels].
         """
@@ -193,7 +193,7 @@ class Array(abstract_array.AbstractArray):
         obj = array.view(cls)
         obj.mask = mask
         obj.exposure_info = exposure_info
-        obj.store_in_1d = store_in_1d
+        obj.store_slim = store_slim
         obj.zoom_for_plot = zoom_for_plot
 
         abstract_array.check_array(array=obj)
@@ -201,32 +201,32 @@ class Array(abstract_array.AbstractArray):
         return obj
 
     @classmethod
-    def manual_1d(
+    def manual_slim(
         cls,
         array,
-        shape_2d,
+        shape_native,
         pixel_scales,
         sub_size=1,
         origin=(0.0, 0.0),
         exposure_info=None,
-        store_in_1d=True,
+        store_slim=True,
     ):
         """
-        Create an Array (see `AbstractArray.__new__`) by inputting the array values in 1D, for example:
+        Create an Array2D (see `AbstractArray2D.__new__`) by inputting the array values in 1D, for example:
 
         array=np.array([1.0, 2.0, 3.0, 4.0])
 
         array=[1.0, 2.0, 3.0, 4.0]
 
-        From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_2d must be
-        input into this method. The mask is setup as a unmasked `Mask2D` of shape_2d.
+        From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_native must be
+        input into this method. The mask is setup as a unmasked `Mask2D` of shape_native.
 
         Parameters
         ----------
         array : np.ndarray or list
             The values of the array input as an ndarray of shape [total_unmasked_pixels*(sub_size**2)] or a list of
             lists.
-        shape_2d : (int, int)
+        shape_native : (int, int)
             The 2D shape of the mask the array is paired with.
         pixel_scales: (float, float) or float
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
@@ -235,43 +235,43 @@ class Array(abstract_array.AbstractArray):
             The size (sub_size x sub_size) of each unmasked pixels sub-array.
         origin : (float, float)
             The (y,x) scaled units origin of the mask's coordinate system.
-        store_in_1d : bool
+        store_slim : bool
             If True, the array is stored in 1D as an ndarray of shape [total_unmasked_pixels]. If False, it is
             stored in 2D as an ndarray of shape [total_y_pixels, total_x_pixels].
         """
 
         pixel_scales = geometry_util.convert_pixel_scales_2d(pixel_scales=pixel_scales)
 
-        if shape_2d is not None and len(shape_2d) != 2:
+        if shape_native is not None and len(shape_native) != 2:
             raise exc.ArrayException(
-                "The input shape_2d parameter is not a tuple of type (float, float)"
+                "The input shape_native parameter is not a tuple of type (float, float)"
             )
 
         mask = msk.Mask2D.unmasked(
-            shape_2d=shape_2d,
+            shape_native=shape_native,
             pixel_scales=pixel_scales,
             sub_size=sub_size,
             origin=origin,
         )
 
-        array = abstract_array.convert_manual_1d_array(
-            array_1d=array, mask=mask, store_in_1d=store_in_1d
+        array = abstract_array.convert_manual_array_slim(
+            array_slim=array, mask=mask, store_slim=store_slim
         )
         return cls(
-            array=array, mask=mask, exposure_info=exposure_info, store_in_1d=store_in_1d
+            array=array, mask=mask, exposure_info=exposure_info, store_slim=store_slim
         )
 
     @classmethod
-    def manual_2d(
+    def manual_native(
         cls,
         array,
         pixel_scales,
         sub_size=1,
         origin=(0.0, 0.0),
         exposure_info=None,
-        store_in_1d=True,
+        store_slim=True,
     ):
-        """Create an Array (see `AbstractArray.__new__`) by inputting the array values in 2D, for example:
+        """Create an Array2D (see `AbstractArray2D.__new__`) by inputting the array values in 2D, for example:
 
         array=np.ndarray([[1.0, 2.0],
                          [3.0, 4.0]])
@@ -280,7 +280,7 @@ class Array(abstract_array.AbstractArray):
               [3.0, 4.0]]
 
         The 2D shape of the array and its mask are determined from the input array and the mask is setup as an
-        unmasked `Mask2D` of shape_2d.
+        unmasked `Mask2D` of shape_native.
 
         Parameters
         ----------
@@ -294,7 +294,7 @@ class Array(abstract_array.AbstractArray):
             The size (sub_size x sub_size) of each unmasked pixels sub-array.
         origin : (float, float)
             The (y,x) scaled units origin of the mask's coordinate system.
-        store_in_1d : bool
+        store_slim : bool
             If True, the array is stored in 1D as an ndarray of shape [total_unmasked_pixels]. If False, it is
             stored in 2D as an ndarray of shape [total_y_pixels, total_x_pixels].
         """
@@ -303,42 +303,42 @@ class Array(abstract_array.AbstractArray):
 
         array = abstract_array.convert_array(array=array)
 
-        shape_2d = (int(array.shape[0] / sub_size), int(array.shape[1] / sub_size))
+        shape_native = (int(array.shape[0] / sub_size), int(array.shape[1] / sub_size))
 
         mask = msk.Mask2D.unmasked(
-            shape_2d=shape_2d,
+            shape_native=shape_native,
             pixel_scales=pixel_scales,
             sub_size=sub_size,
             origin=origin,
         )
 
-        array = abstract_array.convert_manual_2d_array(
-            array_2d=array, mask=mask, store_in_1d=store_in_1d
+        array = abstract_array.convert_manual_native_array(
+            array_2d=array, mask=mask, store_slim=store_slim
         )
-        return cls(array=array, mask=mask, store_in_1d=store_in_1d)
+        return cls(array=array, mask=mask, store_slim=store_slim)
 
     @classmethod
     def manual(
         cls,
         array,
         pixel_scales,
-        shape_2d=None,
+        shape_native=None,
         sub_size=1,
         origin=(0.0, 0.0),
         exposure_info=None,
-        store_in_1d=True,
+        store_slim=True,
     ):
-        """Create an Array (see `AbstractArray.__new__`) by inputting the array values in 1D or 2D, automatically
-        determining whether to use the 'manual_1d' or 'manual_2d' methods.
+        """Create an Array2D (see `AbstractArray2D.__new__`) by inputting the array values in 1D or 2D, automatically
+        determining whether to use the 'manual_slim' or 'manual_native' methods.
 
-        See the manual_1d and manual_2d methods for examples.
+        See the manual_slim and manual_native methods for examples.
 
         Parameters
         ----------
         array : np.ndarray or list
             The values of the array input as an ndarray of shape [total_unmasked_pixels*(sub_size**2)] or a list of
             lists.
-        shape_2d : (int, int)
+        shape_native : (int, int)
             The 2D shape of the mask the array is paired with.
         pixel_scales: (float, float) or float
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
@@ -347,30 +347,30 @@ class Array(abstract_array.AbstractArray):
             The size (sub_size x sub_size) of each unmasked pixels sub-array.
         origin : (float, float)
             The (y,x) scaled units origin of the mask's coordinate system.
-        store_in_1d : bool
+        store_slim : bool
             If True, the array is stored in 1D as an ndarray of shape [total_unmasked_pixels]. If False, it is
             stored in 2D as an ndarray of shape [total_y_pixels, total_x_pixels].
         """
         if len(array.shape) == 1:
-            return cls.manual_1d(
+            return cls.manual_slim(
                 array=array,
                 pixel_scales=pixel_scales,
-                shape_2d=shape_2d,
+                shape_native=shape_native,
                 sub_size=sub_size,
                 origin=origin,
-                store_in_1d=store_in_1d,
+                store_slim=store_slim,
             )
-        return cls.manual_2d(
+        return cls.manual_native(
             array=array,
             pixel_scales=pixel_scales,
             sub_size=sub_size,
             origin=origin,
-            store_in_1d=store_in_1d,
+            store_slim=store_slim,
         )
 
     @classmethod
-    def manual_mask(cls, array, mask, exposure_info=None, store_in_1d=True):
-        """Create an `Array` (see `AbstractArray.__new__`) by inputting the array values in 1D or 2D with its mask,
+    def manual_mask(cls, array, mask, exposure_info=None, store_slim=True):
+        """Create an `Array2D` (see `AbstractArray2D.__new__`) by inputting the array values in 1D or 2D with its mask,
         for example:
 
         mask = Mask2D([[True, False, False, False])
@@ -383,40 +383,40 @@ class Array(abstract_array.AbstractArray):
             lists.
         mask : Mask2D
             The mask whose masked pixels are used to setup the sub-pixel grid.
-        store_in_1d : bool
+        store_slim : bool
             If True, the array is stored in 1D as an ndarray of shape [total_unmasked_pixels]. If False, it is
             stored in 2D as an ndarray of shape [total_y_pixels, total_x_pixels].
         """
         array = abstract_array.convert_manual_array(
-            array=array, mask=mask, store_in_1d=store_in_1d
+            array=array, mask=mask, store_slim=store_slim
         )
         return cls(
-            array=array, mask=mask, exposure_info=exposure_info, store_in_1d=store_in_1d
+            array=array, mask=mask, exposure_info=exposure_info, store_slim=store_slim
         )
 
     @classmethod
     def full(
         cls,
         fill_value,
-        shape_2d,
+        shape_native,
         pixel_scales,
         sub_size=1,
         origin=(0.0, 0.0),
         exposure_info=None,
-        store_in_1d=True,
+        store_slim=True,
     ):
         """
-        Create an `Array` (see `AbstractArray.__new__`) where all values are filled with an input fill value,
+        Create an `Array2D` (see `AbstractArray2D.__new__`) where all values are filled with an input fill value,
         analogous to the method np.full().
 
-        From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_2d must be
-        input into this method. The mask is setup as a unmasked `Mask2D` of shape_2d.
+        From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_native must be
+        input into this method. The mask is setup as a unmasked `Mask2D` of shape_native.
 
         Parameters
         ----------
         fill_value : float
             The value all array elements are filled with.
-        shape_2d : (int, int)
+        shape_native : (int, int)
             The 2D shape of the mask the array is paired with.
         pixel_scales: (float, float) or float
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
@@ -425,40 +425,40 @@ class Array(abstract_array.AbstractArray):
             The size (sub_size x sub_size) of each unmasked pixels sub-array.
         origin : (float, float)
             The (y,x) scaled units origin of the mask's coordinate system.
-        store_in_1d : bool
+        store_slim : bool
             If True, the array is stored in 1D as an ndarray of shape [total_unmasked_pixels]. If False, it is
             stored in 2D as an ndarray of shape [total_y_pixels, total_x_pixels].
         """
         if sub_size is not None:
-            shape_2d = (shape_2d[0] * sub_size, shape_2d[1] * sub_size)
+            shape_native = (shape_native[0] * sub_size, shape_native[1] * sub_size)
 
-        return cls.manual_2d(
-            array=np.full(fill_value=fill_value, shape=shape_2d),
+        return cls.manual_native(
+            array=np.full(fill_value=fill_value, shape=shape_native),
             pixel_scales=pixel_scales,
             sub_size=sub_size,
             origin=origin,
-            store_in_1d=store_in_1d,
+            store_slim=store_slim,
         )
 
     @classmethod
     def ones(
         cls,
-        shape_2d,
+        shape_native,
         pixel_scales,
         sub_size=1,
         origin=(0.0, 0.0),
         exposure_info=None,
-        store_in_1d=True,
+        store_slim=True,
     ):
-        """Create an Array (see `AbstractArray.__new__`) where all values are filled with ones, analogous to the
+        """Create an Array2D (see `AbstractArray2D.__new__`) where all values are filled with ones, analogous to the
         method np.ones().
 
-        From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_2d must be
-        input into this method. The mask is setup as a unmasked `Mask2D` of shape_2d.
+        From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_native must be
+        input into this method. The mask is setup as a unmasked `Mask2D` of shape_native.
 
         Parameters
         ----------
-        shape_2d : (int, int)
+        shape_native : (int, int)
             The 2D shape of the mask the array is paired with.
         pixel_scales: (float, float) or float
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
@@ -467,38 +467,38 @@ class Array(abstract_array.AbstractArray):
             The size (sub_size x sub_size) of each unmasked pixels sub-array.
         origin : (float, float)
             The (y,x) scaled units origin of the mask's coordinate system.
-        store_in_1d : bool
+        store_slim : bool
             If True, the array is stored in 1D as an ndarray of shape [total_unmasked_pixels]. If False, it is
             stored in 2D as an ndarray of shape [total_y_pixels, total_x_pixels].
         """
         return cls.full(
             fill_value=1.0,
-            shape_2d=shape_2d,
+            shape_native=shape_native,
             pixel_scales=pixel_scales,
             sub_size=sub_size,
             origin=origin,
-            store_in_1d=store_in_1d,
+            store_slim=store_slim,
         )
 
     @classmethod
     def zeros(
         cls,
-        shape_2d,
+        shape_native,
         pixel_scales,
         sub_size=1,
         origin=(0.0, 0.0),
         exposure_info=None,
-        store_in_1d=True,
+        store_slim=True,
     ):
-        """Create an Array (see `AbstractArray.__new__`) where all values are filled with zeros, analogous to the
+        """Create an Array2D (see `AbstractArray2D.__new__`) where all values are filled with zeros, analogous to the
         method np.ones().
 
-        From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_2d must be
-        input into this method. The mask is setup as a unmasked `Mask2D` of shape_2d.
+        From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_native must be
+        input into this method. The mask is setup as a unmasked `Mask2D` of shape_native.
 
         Parameters
         ----------
-        shape_2d : (int, int)
+        shape_native : (int, int)
             The 2D shape of the mask the array is paired with.
         pixel_scales: (float, float) or float
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
@@ -507,17 +507,17 @@ class Array(abstract_array.AbstractArray):
             The size (sub_size x sub_size) of each unmasked pixels sub-array.
         origin : (float, float)
             The (y,x) scaled units origin of the mask's coordinate system.
-        store_in_1d : bool
+        store_slim : bool
             If True, the array is stored in 1D as an ndarray of shape [total_unmasked_pixels]. If False, it is
             stored in 2D as an ndarray of shape [total_y_pixels, total_x_pixels].
         """
         return cls.full(
             fill_value=0.0,
-            shape_2d=shape_2d,
+            shape_native=shape_native,
             pixel_scales=pixel_scales,
             sub_size=sub_size,
             origin=origin,
-            store_in_1d=store_in_1d,
+            store_slim=store_slim,
         )
 
     @classmethod
@@ -528,10 +528,10 @@ class Array(abstract_array.AbstractArray):
         hdu=0,
         sub_size=1,
         origin=(0.0, 0.0),
-        store_in_1d=True,
+        store_slim=True,
     ):
         """
-        Create an Array (see `AbstractArray.__new__`) by loading the array values from a .fits file.
+        Create an Array2D (see `AbstractArray2D.__new__`) by loading the array values from a .fits file.
 
         Parameters
         ----------
@@ -547,32 +547,32 @@ class Array(abstract_array.AbstractArray):
             The size (sub_size x sub_size) of each unmasked pixels sub-array.
         origin : (float, float)
             The (y,x) scaled units origin of the mask's coordinate system.
-        store_in_1d : bool
+        store_slim : bool
             If True, the array is stored in 1D as an ndarray of shape [total_unmasked_pixels]. If False, it is
             stored in 2D as an ndarray of shape [total_y_pixels, total_x_pixels].
         """
         array_2d = array_util.numpy_array_2d_from_fits(file_path=file_path, hdu=hdu)
-        return cls.manual_2d(
+        return cls.manual_native(
             array=array_2d,
             pixel_scales=pixel_scales,
             sub_size=sub_size,
             origin=origin,
-            store_in_1d=store_in_1d,
+            store_slim=store_slim,
         )
 
     @classmethod
     def manual_yx_and_values(
-        cls, y, x, values, shape_2d, pixel_scales, sub_size=1, exposure_info=None
+        cls, y, x, values, shape_native, pixel_scales, sub_size=1, exposure_info=None
     ):
-        """Create an `Array` (see `AbstractArray.__new__`) by inputting the y and x pixel values where the array is filled
+        """Create an `Array2D` (see `AbstractArray2D.__new__`) by inputting the y and x pixel values where the array is filled
         and the values to fill the array, for example:
 
         y = np.array([0, 0, 0, 1])
         x = np.array([0, 1, 2, 0])
         value = [1.0, 2.0, 3.0, 4.0]
 
-        From 1D input the method cannot determine the 2D shape of the grid and its mask, thus the shape_2d must be
-        input into this method. The mask is setup as a unmasked `Mask2D` of shape_2d.
+        From 1D input the method cannot determine the 2D shape of the grid and its mask, thus the shape_native must be
+        input into this method. The mask is setup as a unmasked `Mask2D` of shape_native.
 
         Parameters
         ----------
@@ -582,7 +582,7 @@ class Array(abstract_array.AbstractArray):
             The x pixel indexes where value sare input, as an ndarray of shape [total_y_pixels*sub_size] or a list.
         values : np.ndarray or list
             The values which are used too fill in the array.
-        shape_2d : (int, int)
+        shape_native : (int, int)
             The 2D shape of the mask the grid is paired with.
         pixel_scales: (float, float) or float
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
@@ -591,29 +591,31 @@ class Array(abstract_array.AbstractArray):
             The size (sub_size x sub_size) of each unmasked pixels sub-grid.
         origin : (float, float)
             The origin of the grid's mask.
-        store_in_1d : bool
+        store_slim : bool
             If True, the grid is stored in 1D as an ndarray of shape [total_unmasked_pixels, 2]. If False, it is
             stored in 2D as an ndarray of shape [total_y_pixels, total_x_pixels, 2].
         """
         pixel_scales = geometry_util.convert_pixel_scales_2d(pixel_scales=pixel_scales)
 
-        grid = grids.Grid.manual_yx_1d(
-            y=y, x=x, shape_2d=shape_2d, pixel_scales=pixel_scales, sub_size=1
+        grid = grids.Grid2D.manual_yx_1d(
+            y=y, x=x, shape_native=shape_native, pixel_scales=pixel_scales, sub_size=1
         )
 
-        grid_pixels = grid_util.grid_pixel_indexes_1d_from(
-            grid_scaled_1d=grid.in_1d, shape_2d=shape_2d, pixel_scales=pixel_scales
+        grid_pixels = grid_util.grid_pixel_indexes_2d_slim_from(
+            grid_scaled_2d_slim=grid.slim,
+            shape_native=shape_native,
+            pixel_scales=pixel_scales,
         )
 
-        array_1d = np.zeros(shape=shape_2d[0] * shape_2d[1])
+        array_1d = np.zeros(shape=shape_native[0] * shape_native[1])
 
         for i in range(grid_pixels.shape[0]):
             array_1d[i] = values[int(grid_pixels[i])]
 
-        return cls.manual_1d(
+        return cls.manual_slim(
             array=array_1d,
             pixel_scales=pixel_scales,
-            shape_2d=shape_2d,
+            shape_native=shape_native,
             sub_size=sub_size,
             exposure_info=exposure_info,
         )
