@@ -10,15 +10,15 @@ from autoarray.util import array_util
 from autoarray import exc
 
 
-class Kernel(arrays.Array):
+class Kernel2D(arrays.Array2D):
 
     # noinspection PyUnusedLocal
     def __new__(cls, array, mask, renormalize=False, *args, **kwargs):
         """An array of values, which are paired to a uniform 2D mask of pixels and sub-pixels. Each entry
-        on the array corresponds to a value at the centre of a sub-pixel in an unmasked pixel. See the *Array* class
+        on the array corresponds to a value at the centre of a sub-pixel in an unmasked pixel. See the *Array2D* class
         for a full description of how Arrays work.
 
-        The *Kernel* class is an *Array* but with additioonal methods that allow it to be convolved with data.
+        The *Kernel2D* class is an *Array2D* but with additioonal methods that allow it to be convolved with data.
 
         Parameters
         ----------
@@ -28,9 +28,9 @@ class Kernel(arrays.Array):
             The 2D mask associated with the array, defining the pixels each array value is paired with and
             originates from.
         renormalize : bool
-            If True, the Kernel's array values are renormalized such that they sum to 1.0.
+            If True, the Kernel2D's array values are renormalized such that they sum to 1.0.
         """
-        obj = super(Kernel, cls).__new__(cls=cls, array=array, mask=mask)
+        obj = super(Kernel2D, cls).__new__(cls=cls, array=array, mask=mask)
 
         if renormalize:
             obj[:] = np.divide(obj, np.sum(obj))
@@ -38,24 +38,24 @@ class Kernel(arrays.Array):
         return obj
 
     @classmethod
-    def manual_1d(
-        cls, array, shape_2d, pixel_scales, origin=(0.0, 0.0), renormalize=False
+    def manual_slim(
+        cls, array, shape_native, pixel_scales, origin=(0.0, 0.0), renormalize=False
     ):
-        """Create a Kernel (see *Kernel.__new__*) by inputting the kernel values in 1D, for example:
+        """Create a Kernel2D (see *Kernel2D.__new__*) by inputting the kernel values in 1D, for example:
 
         kernel=np.array([1.0, 2.0, 3.0, 4.0])
 
         kernel=[1.0, 2.0, 3.0, 4.0]
 
-        From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_2d must be
-        input into this method. The mask is setup as a unmasked `Mask2D` of shape_2d.
+        From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_native must be
+        input into this method. The mask is setup as a unmasked `Mask2D` of shape_native.
 
         Parameters
         ----------
         array : np.ndarray or list
             The values of the array input as an ndarray of shape [total_unmasked_pixels*(sub_size**2)] or a list of
             lists.
-        shape_2d : (float, float)
+        shape_native : (float, float)
             The 2D shape of the mask the array is paired with.
         pixel_scales: (float, float) or float
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
@@ -65,17 +65,20 @@ class Kernel(arrays.Array):
         origin : (float, float)
             The (y,x) scaled units origin of the mask's coordinate system.
         renormalize : bool
-            If True, the Kernel's array values are renormalized such that they sum to 1.0.
+            If True, the Kernel2D's array values are renormalized such that they sum to 1.0.
         """
-        array = arrays.Array.manual_1d(
-            array=array, shape_2d=shape_2d, pixel_scales=pixel_scales, origin=origin
+        array = arrays.Array2D.manual_slim(
+            array=array,
+            shape_native=shape_native,
+            pixel_scales=pixel_scales,
+            origin=origin,
         )
 
         return cls(array=array, mask=array.mask, renormalize=renormalize)
 
     @classmethod
-    def manual_2d(cls, array, pixel_scales, origin=(0.0, 0.0), renormalize=False):
-        """Create an Kernel (see *Kernel.__new__*) by inputting the kernel values in 2D, for example:
+    def manual_native(cls, array, pixel_scales, origin=(0.0, 0.0), renormalize=False):
+        """Create an Kernel2D (see *Kernel2D.__new__*) by inputting the kernel values in 2D, for example:
 
         kernel=np.ndarray([[1.0, 2.0],
                          [3.0, 4.0]])
@@ -84,7 +87,7 @@ class Kernel(arrays.Array):
               [3.0, 4.0]]
 
         The 2D shape of the array and its mask are determined from the input array and the mask is setup as an
-        unmasked `Mask2D` of shape_2d.
+        unmasked `Mask2D` of shape_native.
 
         Parameters
         ----------
@@ -99,9 +102,9 @@ class Kernel(arrays.Array):
         origin : (float, float)
             The (y,x) scaled units origin of the mask's coordinate system.
         renormalize : bool
-            If True, the Kernel's array values are renormalized such that they sum to 1.0.
+            If True, the Kernel2D's array values are renormalized such that they sum to 1.0.
         """
-        array = arrays.Array.manual_2d(
+        array = arrays.Array2D.manual_native(
             array=array, pixel_scales=pixel_scales, origin=origin
         )
 
@@ -109,18 +112,23 @@ class Kernel(arrays.Array):
 
     @classmethod
     def manual(
-        cls, array, pixel_scales, shape_2d=None, origin=(0.0, 0.0), renormalize=False
+        cls,
+        array,
+        pixel_scales,
+        shape_native=None,
+        origin=(0.0, 0.0),
+        renormalize=False,
     ):
-        """Create a Kernel (see *Kernel.__new__*) by inputting the kernel values in 1D or 2D, automatically
-        determining whether to use the 'manual_1d' or 'manual_2d' methods.
+        """Create a Kernel2D (see *Kernel2D.__new__*) by inputting the kernel values in 1D or 2D, automatically
+        determining whether to use the 'manual_slim' or 'manual_native' methods.
 
-        See the manual_1d and manual_2d methods for examples.
+        See the manual_slim and manual_native methods for examples.
         Parameters
         ----------
         array : np.ndarray or list
             The values of the array input as an ndarray of shape [total_unmasked_pixels*(sub_size**2)] or a list of
             lists.
-        shape_2d : (float, float)
+        shape_native : (float, float)
             The 2D shape of the mask the array is paired with.
         pixel_scales: (float, float) or float
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
@@ -130,17 +138,17 @@ class Kernel(arrays.Array):
         origin : (float, float)
             The (y,x) scaled units origin of the mask's coordinate system.
         renormalize : bool
-            If True, the Kernel's array values are renormalized such that they sum to 1.0.
+            If True, the Kernel2D's array values are renormalized such that they sum to 1.0.
         """
         if len(array.shape) == 1:
-            return cls.manual_1d(
+            return cls.manual_slim(
                 array=array,
-                shape_2d=shape_2d,
+                shape_native=shape_native,
                 pixel_scales=pixel_scales,
                 origin=origin,
                 renormalize=renormalize,
             )
-        return cls.manual_2d(
+        return cls.manual_native(
             array=array,
             pixel_scales=pixel_scales,
             origin=origin,
@@ -151,23 +159,23 @@ class Kernel(arrays.Array):
     def full(
         cls,
         fill_value,
-        shape_2d,
+        shape_native,
         pixel_scales,
         sub_size=1,
         origin=(0.0, 0.0),
         renormalize=False,
     ):
-        """Create a Kernel (see *Kernel.__new__*) where all values are filled with an input fill value, analogous to
+        """Create a Kernel2D (see *Kernel2D.__new__*) where all values are filled with an input fill value, analogous to
          the method numpy ndarray.full.
 
-        From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_2d must be
-        input into this method. The mask is setup as a unmasked `Mask2D` of shape_2d.
+        From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_native must be
+        input into this method. The mask is setup as a unmasked `Mask2D` of shape_native.
 
         Parameters
         ----------
         fill_value : float
             The value all array elements are filled with.
-        shape_2d : (float, float)
+        shape_native : (float, float)
             The 2D shape of the mask the array is paired with.
         pixel_scales: (float, float) or float
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
@@ -177,29 +185,29 @@ class Kernel(arrays.Array):
         origin : (float, float)
             The (y,x) scaled units origin of the mask's coordinate system.
         renormalize : bool
-            If True, the Kernel's array values are renormalized such that they sum to 1.0.
+            If True, the Kernel2D's array values are renormalized such that they sum to 1.0.
         """
         if sub_size is not None:
-            shape_2d = (shape_2d[0] * sub_size, shape_2d[1] * sub_size)
+            shape_native = (shape_native[0] * sub_size, shape_native[1] * sub_size)
 
-        return cls.manual_2d(
-            array=np.full(fill_value=fill_value, shape=shape_2d),
+        return cls.manual_native(
+            array=np.full(fill_value=fill_value, shape=shape_native),
             pixel_scales=pixel_scales,
             origin=origin,
             renormalize=renormalize,
         )
 
     @classmethod
-    def ones(cls, shape_2d, pixel_scales, origin=(0.0, 0.0), renormalize=False):
-        """Create an Kernel (see *Kernel.__new__*) where all values are filled with ones, analogous to the method numpy
+    def ones(cls, shape_native, pixel_scales, origin=(0.0, 0.0), renormalize=False):
+        """Create an Kernel2D (see *Kernel2D.__new__*) where all values are filled with ones, analogous to the method numpy
         ndarray.ones.
 
-        From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_2d must be
-        input into this method. The mask is setup as a unmasked `Mask2D` of shape_2d.
+        From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_native must be
+        input into this method. The mask is setup as a unmasked `Mask2D` of shape_native.
 
         Parameters
         ----------
-        shape_2d : (float, float)
+        shape_native : (float, float)
             The 2D shape of the mask the array is paired with.
         pixel_scales: (float, float) or float
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
@@ -209,27 +217,27 @@ class Kernel(arrays.Array):
         origin : (float, float)
             The (y,x) scaled units origin of the mask's coordinate system.
         renormalize : bool
-            If True, the Kernel's array values are renormalized such that they sum to 1.0.
+            If True, the Kernel2D's array values are renormalized such that they sum to 1.0.
         """
         return cls.full(
             fill_value=1.0,
-            shape_2d=shape_2d,
+            shape_native=shape_native,
             pixel_scales=pixel_scales,
             origin=origin,
             renormalize=renormalize,
         )
 
     @classmethod
-    def zeros(cls, shape_2d, pixel_scales, origin=(0.0, 0.0), renormalize=False):
-        """Create an Kernel (see *Kernel.__new__*) where all values are filled with zeros, analogous to the method numpy
+    def zeros(cls, shape_native, pixel_scales, origin=(0.0, 0.0), renormalize=False):
+        """Create an Kernel2D (see *Kernel2D.__new__*) where all values are filled with zeros, analogous to the method numpy
         ndarray.ones.
 
-        From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_2d must be
-        input into this method. The mask is setup as a unmasked `Mask2D` of shape_2d.
+        From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_native must be
+        input into this method. The mask is setup as a unmasked `Mask2D` of shape_native.
 
         Parameters
         ----------
-        shape_2d : (float, float)
+        shape_native : (float, float)
             The 2D shape of the mask the array is paired with.
         pixel_scales: (float, float) or float
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
@@ -239,11 +247,11 @@ class Kernel(arrays.Array):
         origin : (float, float)
             The (y,x) scaled units origin of the mask's coordinate system.
         renormalize : bool
-            If True, the Kernel's array values are renormalized such that they sum to 1.0.
+            If True, the Kernel2D's array values are renormalized such that they sum to 1.0.
         """
         return cls.full(
             fill_value=0.0,
-            shape_2d=shape_2d,
+            shape_native=shape_native,
             pixel_scales=pixel_scales,
             origin=origin,
             renormalize=renormalize,
@@ -251,7 +259,7 @@ class Kernel(arrays.Array):
 
     @classmethod
     def no_blur(cls, pixel_scales):
-        """Setup the Kernel as a kernel which does not convolve any signal, which is simply an array of shape (1, 1)
+        """Setup the Kernel2D as a kernel which does not convolve any signal, which is simply an array of shape (1, 1)
         with value 1.
 
         Parameters
@@ -263,12 +271,12 @@ class Kernel(arrays.Array):
 
         array = np.array([[1.0]])
 
-        return cls.manual_2d(array=array, pixel_scales=pixel_scales)
+        return cls.manual_native(array=array, pixel_scales=pixel_scales)
 
     @classmethod
     def from_gaussian(
         cls,
-        shape_2d,
+        shape_native,
         pixel_scales,
         sigma,
         centre=(0.0, 0.0),
@@ -276,14 +284,14 @@ class Kernel(arrays.Array):
         phi=0.0,
         renormalize=False,
     ):
-        """Setup the Kernel as a 2D symmetric elliptical Gaussian profile, according to the equation:
+        """Setup the Kernel2D as a 2D symmetric elliptical Gaussian profile, according to the equation:
 
         (1.0 / (sigma * sqrt(2.0*pi))) * exp(-0.5 * (r/sigma)**2)
 
 
         Parameters
         ----------
-        shape_2d : (float, float)
+        shape_native : (float, float)
             The 2D shape of the mask the array is paired with.
         pixel_scales: (float, float) or float
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
@@ -297,10 +305,12 @@ class Kernel(arrays.Array):
         phi : float
             The rotational angle of the Gaussian's ellipse defined counter clockwise from the positive x-axis.
         renormalize : bool
-            If True, the Kernel's array values are renormalized such that they sum to 1.0.
+            If True, the Kernel2D's array values are renormalized such that they sum to 1.0.
         """
 
-        grid = grids.Grid.uniform(shape_2d=shape_2d, pixel_scales=pixel_scales)
+        grid = grids.Grid2D.uniform(
+            shape_native=shape_native, pixel_scales=pixel_scales
+        )
         grid_shifted = np.subtract(grid, centre)
         grid_radius = np.sqrt(np.sum(grid_shifted ** 2.0, 1))
         theta_coordinate_to_profile = np.arctan2(
@@ -325,9 +335,9 @@ class Kernel(arrays.Array):
             np.exp(-0.5 * np.square(np.divide(grid_elliptical_radii, sigma))),
         )
 
-        return cls.manual_1d(
+        return cls.manual_slim(
             array=gaussian,
-            shape_2d=shape_2d,
+            shape_native=shape_native,
             pixel_scales=pixel_scales,
             renormalize=renormalize,
         )
@@ -335,7 +345,7 @@ class Kernel(arrays.Array):
     @classmethod
     def from_as_gaussian_via_alma_fits_header_parameters(
         cls,
-        shape_2d,
+        shape_native,
         pixel_scales,
         y_stddev,
         x_stddev,
@@ -354,7 +364,7 @@ class Kernel(arrays.Array):
         axis_ratio = x_stddev / y_stddev
 
         return cls.from_gaussian(
-            shape_2d=shape_2d,
+            shape_native=shape_native,
             pixel_scales=pixel_scales,
             sigma=y_stddev,
             axis_ratio=axis_ratio,
@@ -368,7 +378,7 @@ class Kernel(arrays.Array):
         cls, file_path, hdu, pixel_scales, origin=(0.0, 0.0), renormalize=False
     ):
         """
-        Loads the Kernel from a .fits file.
+        Loads the Kernel2D from a .fits file.
 
         Parameters
         ----------
@@ -383,10 +393,10 @@ class Kernel(arrays.Array):
         origin : (float, float)
             The (y,x) scaled units origin of the mask's coordinate system.
         renormalize : bool
-            If True, the Kernel's array values are renormalized such that they sum to 1.0.
+            If True, the Kernel2D's array values are renormalized such that they sum to 1.0.
         """
 
-        array = arrays.Array.from_fits(
+        array = arrays.Array2D.from_fits(
             file_path=file_path, hdu=hdu, pixel_scales=pixel_scales, origin=origin
         )
 
@@ -416,7 +426,7 @@ class Kernel(arrays.Array):
         """
 
         kernel_rescaled = rescale(
-            self.in_2d,
+            self.native,
             rescale_factor,
             anti_aliasing=False,
             mode="constant",
@@ -464,33 +474,33 @@ class Kernel(arrays.Array):
 
             pixel_scales = None
 
-        return self.__class__.manual_2d(
+        return self.__class__.manual_native(
             array=kernel_rescaled, pixel_scales=pixel_scales, renormalize=renormalize
         )
 
     @property
-    def in_2d(self):
+    def native(self):
         """Convenience method to access the kerne;'s 2D representation, which is an ndarray of shape
         [sub_size*total_y_pixels, sub_size*total_x_pixels, 2] where all masked values are given values (0.0, 0.0).
 
         If the array is stored in 2D it is return as is. If it is stored in 1D, it must first be mapped from 1D to 2D."""
         return array_util.sub_array_2d_from(
-            sub_array_1d=self, mask=self.mask, sub_size=self.mask.sub_size
+            sub_array_2d_slim=self, mask_2d=self.mask, sub_size=self.mask.sub_size
         )
 
     @property
     def renormalized(self):
-        """Renormalize the Kernel such that its data_vector values sum to unity."""
+        """Renormalize the Kernel2D such that its data_vector values sum to unity."""
         return self.__class__(array=self, mask=self.mask, renormalize=True)
 
     def convolved_array_from_array(self, array):
         """
-        Convolve an array with this Kernel
+        Convolve an array with this Kernel2D
 
         Parameters
         ----------
         image : np.ndarray
-            An array representing the image the Kernel is convolved with.
+            An array representing the image the Kernel2D is convolved with.
 
         Returns
         -------
@@ -499,33 +509,33 @@ class Kernel(arrays.Array):
 
         Raises
         ------
-        KernelException if either Kernel psf dimension is odd
+        KernelException if either Kernel2D psf dimension is odd
         """
         if self.mask.shape[0] % 2 == 0 or self.mask.shape[1] % 2 == 0:
-            raise exc.KernelException("Kernel Kernel must be odd")
+            raise exc.KernelException("Kernel2D Kernel2D must be odd")
 
-        array_binned_2d = array.in_2d_binned
+        array_binned_2d = array.native_binned
 
         convolved_array_2d = scipy.signal.convolve2d(
-            array_binned_2d, self.in_2d, mode="same"
+            array_binned_2d, self.native, mode="same"
         )
 
-        convolved_array_1d = array_util.sub_array_1d_from(
-            mask=array_binned_2d.mask, sub_array_2d=convolved_array_2d, sub_size=1
+        convolved_array_1d = array_util.sub_array_2d_slim_from(
+            mask_2d=array_binned_2d.mask, sub_array_2d=convolved_array_2d, sub_size=1
         )
 
-        return arrays.Array(
-            array=convolved_array_1d, mask=array_binned_2d.mask, store_in_1d=True
+        return arrays.Array2D(
+            array=convolved_array_1d, mask=array_binned_2d.mask, store_slim=True
         )
 
     def convolved_array_from_array_2d_and_mask(self, array_2d, mask):
         """
-        Convolve an array with this Kernel
+        Convolve an array with this Kernel2D
 
         Parameters
         ----------
         image : np.ndarray
-            An array representing the image the Kernel is convolved with.
+            An array representing the image the Kernel2D is convolved with.
 
         Returns
         -------
@@ -534,18 +544,18 @@ class Kernel(arrays.Array):
 
         Raises
         ------
-        KernelException if either Kernel psf dimension is odd
+        KernelException if either Kernel2D psf dimension is odd
         """
 
         if self.mask.shape[0] % 2 == 0 or self.mask.shape[1] % 2 == 0:
-            raise exc.KernelException("Kernel Kernel must be odd")
+            raise exc.KernelException("Kernel2D Kernel2D must be odd")
 
-        convolved_array_2d = scipy.signal.convolve2d(array_2d, self.in_2d, mode="same")
+        convolved_array_2d = scipy.signal.convolve2d(array_2d, self.native, mode="same")
 
-        convolved_array_1d = array_util.sub_array_1d_from(
-            mask=mask, sub_array_2d=convolved_array_2d, sub_size=1
+        convolved_array_1d = array_util.sub_array_2d_slim_from(
+            mask_2d=mask, sub_array_2d=convolved_array_2d, sub_size=1
         )
 
-        return arrays.Array(
-            array=convolved_array_1d, mask=mask.mask_sub_1, store_in_1d=True
+        return arrays.Array2D(
+            array=convolved_array_1d, mask=mask.mask_sub_1, store_slim=True
         )
