@@ -1,14 +1,14 @@
 import autoarray as aa
 import autoarray.plot as aplt
 
-array = aa.Array.ones(shape_2d=(31, 31), pixel_scales=(1.0, 1.0), sub_size=2)
+array = aa.Array2D.ones(shape_native=(31, 31), pixel_scales=(1.0, 1.0), sub_size=2)
 array[0] = 3.0
 
 mask = aa.Mask2D.circular(
-    shape_2d=array.shape_2d,
+    shape_native=array.shape_native,
     pixel_scales=array.pixel_scales,
     radius=5.0,
     centre=(2.0, 2.0),
 )
 
-aplt.Array(array=array, mask=mask, include_border=True)
+aplt.Array2D(array=array, mask=mask, include_border=True)
