@@ -15,22 +15,24 @@ test_values_dir = path.join(
 
 def test__indexes_give_entries_where_list_begin_and_end():
 
-    values = aa.Values(values=[[0.0]])
+    values = aa.ValuesIrregularGrouped(values=[[0.0]])
 
     assert values.lower_indexes == [0]
     assert values.upper_indexes == [1]
 
-    values = aa.Values(values=[[0.0, 0.0]])
+    values = aa.ValuesIrregularGrouped(values=[[0.0, 0.0]])
 
     assert values.lower_indexes == [0]
     assert values.upper_indexes == [2]
 
-    values = aa.Values(values=[[0.0, 0.0], [0.0]])
+    values = aa.ValuesIrregularGrouped(values=[[0.0, 0.0], [0.0]])
 
     assert values.lower_indexes == [0, 2]
     assert values.upper_indexes == [2, 3]
 
-    values = aa.Values(values=[[0.0, 0.0], [0.0, 0.0, 0.0], [0.0, 0.0], [0.0]])
+    values = aa.ValuesIrregularGrouped(
+        values=[[0.0, 0.0], [0.0, 0.0, 0.0], [0.0, 0.0], [0.0]]
+    )
 
     assert values.lower_indexes == [0, 2, 5, 7]
     assert values.upper_indexes == [2, 5, 7, 8]
@@ -38,71 +40,71 @@ def test__indexes_give_entries_where_list_begin_and_end():
 
 def test__input_as_list__convert_correctly():
 
-    values = aa.Values(values=[1.0, -1.0])
+    values = aa.ValuesIrregularGrouped(values=[1.0, -1.0])
 
-    assert type(values) == arrays.Values
+    assert type(values) == arrays.ValuesIrregularGrouped
     assert (values == np.array([1.0, -1.0])).all()
     assert values.in_grouped_list == [[1.0, -1.0]]
-    assert values.in_1d_list == [1.0, -1.0]
+    assert values.in_list == [1.0, -1.0]
 
-    values = aa.Values(values=[[1.0], [-1.0]])
+    values = aa.ValuesIrregularGrouped(values=[[1.0], [-1.0]])
 
-    assert type(values) == arrays.Values
+    assert type(values) == arrays.ValuesIrregularGrouped
     assert (values == np.array([1.0, -1.0])).all()
     assert values.in_grouped_list == [[1.0], [-1.0]]
-    assert values.in_1d_list == [1.0, -1.0]
+    assert values.in_list == [1.0, -1.0]
 
 
 def test__input_as_dict__retains_dict_and_converts_correctly():
 
-    values = aa.Values(values=dict(source_0=1.0, source_1=-1.0))
+    values = aa.ValuesIrregularGrouped(values=dict(source_0=1.0, source_1=-1.0))
 
-    assert type(values) == arrays.Values
+    assert type(values) == arrays.ValuesIrregularGrouped
     assert (values == np.array([1.0, -1.0])).all()
     assert values.in_grouped_list == [[1.0, -1.0]]
-    assert values.in_1d_list == [1.0, -1.0]
+    assert values.in_list == [1.0, -1.0]
     assert values.as_dict["source_0"] == 1.0
     assert values.as_dict["source_1"] == -1.0
 
-    values = aa.Values(values=dict(source_0=[1.0], source_1=[-1.0]))
+    values = aa.ValuesIrregularGrouped(values=dict(source_0=[1.0], source_1=[-1.0]))
 
-    assert type(values) == arrays.Values
+    assert type(values) == arrays.ValuesIrregularGrouped
     assert (values == np.array([1.0, -1.0])).all()
     assert values.in_grouped_list == [[1.0], [-1.0]]
-    assert values.in_1d_list == [1.0, -1.0]
+    assert values.in_list == [1.0, -1.0]
     assert values.as_dict["source_0"] == [1.0]
     assert values.as_dict["source_1"] == [-1.0]
 
 
-def test__values_from_arr_1d():
+def test__values_from_array_slim():
 
-    values = aa.Values(values=[[1.0, 2.0]])
+    values = aa.ValuesIrregularGrouped(values=[[1.0, 2.0]])
 
-    values_from_1d = values.values_from_arr_1d(arr_1d=np.array([1.0, 2.0]))
+    values_from_1d = values.values_from_array_slim(array_slim=np.array([1.0, 2.0]))
 
     assert values_from_1d.in_grouped_list == [[1.0, 2.0]]
 
-    values = aa.Values(values=[[1.0, 2.0], [3.0]])
+    values = aa.ValuesIrregularGrouped(values=[[1.0, 2.0], [3.0]])
 
-    values_from_1d = values.values_from_arr_1d(arr_1d=np.array([1.0, 2.0, 3.0]))
+    values_from_1d = values.values_from_array_slim(array_slim=np.array([1.0, 2.0, 3.0]))
 
     assert values_from_1d.in_grouped_list == [[1.0, 2.0], [3.0]]
 
 
 def test__coordinates_from_grid_1d():
 
-    values = aa.Values(values=[[1.0, 2.0]])
+    values = aa.ValuesIrregularGrouped(values=[[1.0, 2.0]])
 
-    coordinate_from_1d = values.grid_from_grid_1d(
-        grid_1d=np.array([[1.0, 1.0], [2.0, 2.0]])
+    coordinate_from_1d = values.grid_from_grid_slim(
+        grid_slim=np.array([[1.0, 1.0], [2.0, 2.0]])
     )
 
     assert coordinate_from_1d.in_grouped_list == [[(1.0, 1.0), (2.0, 2.0)]]
 
-    values = aa.Values(values=[[1.0, 2.0], [3.0]])
+    values = aa.ValuesIrregularGrouped(values=[[1.0, 2.0], [3.0]])
 
-    coordinate_from_1d = values.grid_from_grid_1d(
-        grid_1d=np.array([[1.0, 1.0], [2.0, 2.0], [3.0, 3.0]])
+    coordinate_from_1d = values.grid_from_grid_slim(
+        grid_slim=np.array([[1.0, 1.0], [2.0, 2.0], [3.0, 3.0]])
     )
 
     assert coordinate_from_1d.in_grouped_list == [
@@ -112,7 +114,7 @@ def test__coordinates_from_grid_1d():
 
 
 def test__load_values__retains_list_structure():
-    values = aa.Values.from_file(
+    values = aa.ValuesIrregularGrouped.from_file(
         file_path=path.join(test_values_dir, "values_test.dat")
     )
 
@@ -121,7 +123,7 @@ def test__load_values__retains_list_structure():
 
 def test__output_values_to_file():
 
-    values = aa.Values([[4.0, 5.0], [6.0, 7.0, 8.0]])
+    values = aa.ValuesIrregularGrouped([[4.0, 5.0], [6.0, 7.0, 8.0]])
 
     output_values_dir = "{}/files/values/output_test/".format(
         path.dirname(path.realpath(__file__))
@@ -133,7 +135,9 @@ def test__output_values_to_file():
 
     values.output_to_file(file_path=output_values_dir + "values_test.dat")
 
-    values = aa.Values.from_file(file_path=output_values_dir + "values_test.dat")
+    values = aa.ValuesIrregularGrouped.from_file(
+        file_path=output_values_dir + "values_test.dat"
+    )
 
     assert values.in_grouped_list == [[4.0, 5.0], [6.0, 7.0, 8.0]]
 
