@@ -200,18 +200,14 @@ class TestPixelizationResiduals:
 
         pixelization_values = np.ones(3)
         reconstructed_data_1d = np.ones(9)
-        mask_1d_index_for_sub_mask_1d_index = np.array([0, 1, 2, 3, 4, 5, 6, 7, 8])
-        all_sub_mask_1d_indexes_for_pixelization_1d_index = [
-            [0, 0, 0],
-            [1, 1, 1],
-            [2, 2, 2],
-        ]
+        slim_index_for_sub_slim_index = np.array([0, 1, 2, 3, 4, 5, 6, 7, 8])
+        all_sub_slim_indexes_for_pixelization_index = [[0, 0, 0], [1, 1, 1], [2, 2, 2]]
 
         pixelization_residuals = aa.util.inversion.inversion_residual_map_from(
             pixelization_values=pixelization_values,
             data=reconstructed_data_1d,
-            mask_1d_index_for_sub_mask_1d_index=mask_1d_index_for_sub_mask_1d_index,
-            all_sub_mask_1d_indexes_for_pixelization_1d_index=all_sub_mask_1d_indexes_for_pixelization_1d_index,
+            slim_index_for_sub_slim_index=slim_index_for_sub_slim_index,
+            all_sub_slim_indexes_for_pixelization_index=all_sub_slim_indexes_for_pixelization_index,
         )
 
         assert (pixelization_residuals == np.zeros(3)).all()
@@ -220,36 +216,28 @@ class TestPixelizationResiduals:
 
         pixelization_values = np.ones(3)
         reconstructed_data_1d = 2.0 * np.ones(9)
-        mask_1d_index_for_sub_mask_1d_index = np.array([0, 1, 2, 3, 4, 5, 6, 7, 8])
-        all_sub_mask_1d_indexes_for_pixelization_1d_index = [
-            [0, 1, 2],
-            [3, 4, 5],
-            [6, 7, 8],
-        ]
+        slim_index_for_sub_slim_index = np.array([0, 1, 2, 3, 4, 5, 6, 7, 8])
+        all_sub_slim_indexes_for_pixelization_index = [[0, 1, 2], [3, 4, 5], [6, 7, 8]]
 
         pixelization_residuals = aa.util.inversion.inversion_residual_map_from(
             pixelization_values=pixelization_values,
             data=reconstructed_data_1d,
-            mask_1d_index_for_sub_mask_1d_index=mask_1d_index_for_sub_mask_1d_index,
-            all_sub_mask_1d_indexes_for_pixelization_1d_index=all_sub_mask_1d_indexes_for_pixelization_1d_index,
+            slim_index_for_sub_slim_index=slim_index_for_sub_slim_index,
+            all_sub_slim_indexes_for_pixelization_index=all_sub_slim_indexes_for_pixelization_index,
         )
 
         assert (pixelization_residuals == 1.0 * np.ones(3)).all()
 
         pixelization_values = np.ones(3)
         reconstructed_data_1d = np.array([1.0, 1.0, 1.0, 2.0, 2.0, 2.0, 3.0, 3.0, 3.0])
-        mask_1d_index_for_sub_mask_1d_index = np.array([0, 1, 2, 3, 4, 5, 6, 7, 8])
-        all_sub_mask_1d_indexes_for_pixelization_1d_index = [
-            [0, 1, 2],
-            [3, 4, 5],
-            [6, 7, 8],
-        ]
+        slim_index_for_sub_slim_index = np.array([0, 1, 2, 3, 4, 5, 6, 7, 8])
+        all_sub_slim_indexes_for_pixelization_index = [[0, 1, 2], [3, 4, 5], [6, 7, 8]]
 
         pixelization_residuals = aa.util.inversion.inversion_residual_map_from(
             pixelization_values=pixelization_values,
             data=reconstructed_data_1d,
-            mask_1d_index_for_sub_mask_1d_index=mask_1d_index_for_sub_mask_1d_index,
-            all_sub_mask_1d_indexes_for_pixelization_1d_index=all_sub_mask_1d_indexes_for_pixelization_1d_index,
+            slim_index_for_sub_slim_index=slim_index_for_sub_slim_index,
+            all_sub_slim_indexes_for_pixelization_index=all_sub_slim_indexes_for_pixelization_index,
         )
 
         assert (pixelization_residuals == np.array([0.0, 1.0, 2.0])).all()
@@ -263,19 +251,15 @@ class TestPixelizationNormalizedResiduals:
         pixelization_values = np.ones(3)
         reconstructed_data_1d = np.ones(9)
         noise_map_1d = np.ones(9)
-        mask_1d_index_for_sub_mask_1d_index = np.array([0, 1, 2, 3, 4, 5, 6, 7, 8])
-        all_sub_mask_1d_indexes_for_pixelization_1d_index = [
-            [0, 0, 0],
-            [1, 1, 1],
-            [2, 2, 2],
-        ]
+        slim_index_for_sub_slim_index = np.array([0, 1, 2, 3, 4, 5, 6, 7, 8])
+        all_sub_slim_indexes_for_pixelization_index = [[0, 0, 0], [1, 1, 1], [2, 2, 2]]
 
         pixelization_normalized_residuals = aa.util.inversion.inversion_normalized_residual_map_from(
             pixelization_values=pixelization_values,
             data=reconstructed_data_1d,
             noise_map_1d=noise_map_1d,
-            mask_1d_index_for_sub_mask_1d_index=mask_1d_index_for_sub_mask_1d_index,
-            all_sub_mask_1d_indexes_for_pixelization_1d_index=all_sub_mask_1d_indexes_for_pixelization_1d_index,
+            slim_index_for_sub_slim_index=slim_index_for_sub_slim_index,
+            all_sub_slim_indexes_for_pixelization_index=all_sub_slim_indexes_for_pixelization_index,
         )
 
         assert (pixelization_normalized_residuals == np.zeros(3)).all()
@@ -285,19 +269,15 @@ class TestPixelizationNormalizedResiduals:
         pixelization_values = np.ones(3)
         reconstructed_data_1d = 2.0 * np.ones(9)
         noise_map_1d = 2.0 * np.ones(9)
-        mask_1d_index_for_sub_mask_1d_index = np.array([0, 1, 2, 3, 4, 5, 6, 7, 8])
-        all_sub_mask_1d_indexes_for_pixelization_1d_index = [
-            [0, 1, 2],
-            [3, 4, 5],
-            [6, 7, 8],
-        ]
+        slim_index_for_sub_slim_index = np.array([0, 1, 2, 3, 4, 5, 6, 7, 8])
+        all_sub_slim_indexes_for_pixelization_index = [[0, 1, 2], [3, 4, 5], [6, 7, 8]]
 
         pixelization_normalized_residuals = aa.util.inversion.inversion_normalized_residual_map_from(
             pixelization_values=pixelization_values,
             data=reconstructed_data_1d,
             noise_map_1d=noise_map_1d,
-            mask_1d_index_for_sub_mask_1d_index=mask_1d_index_for_sub_mask_1d_index,
-            all_sub_mask_1d_indexes_for_pixelization_1d_index=all_sub_mask_1d_indexes_for_pixelization_1d_index,
+            slim_index_for_sub_slim_index=slim_index_for_sub_slim_index,
+            all_sub_slim_indexes_for_pixelization_index=all_sub_slim_indexes_for_pixelization_index,
         )
 
         assert (pixelization_normalized_residuals == 0.5 * np.ones(3)).all()
@@ -305,19 +285,15 @@ class TestPixelizationNormalizedResiduals:
         pixelization_values = np.ones(3)
         reconstructed_data_1d = np.array([1.0, 1.0, 1.0, 2.0, 2.0, 2.0, 3.0, 3.0, 3.0])
         noise_map_1d = np.array([0.5, 0.5, 0.5, 1.0, 1.0, 1.0, 2.0, 2.0, 2.0])
-        mask_1d_index_for_sub_mask_1d_index = np.array([0, 1, 2, 3, 4, 5, 6, 7, 8])
-        all_sub_mask_1d_indexes_for_pixelization_1d_index = [
-            [0, 1, 2],
-            [3, 4, 5],
-            [6, 7, 8],
-        ]
+        slim_index_for_sub_slim_index = np.array([0, 1, 2, 3, 4, 5, 6, 7, 8])
+        all_sub_slim_indexes_for_pixelization_index = [[0, 1, 2], [3, 4, 5], [6, 7, 8]]
 
         pixelization_normalized_residuals = aa.util.inversion.inversion_normalized_residual_map_from(
             pixelization_values=pixelization_values,
             data=reconstructed_data_1d,
             noise_map_1d=noise_map_1d,
-            mask_1d_index_for_sub_mask_1d_index=mask_1d_index_for_sub_mask_1d_index,
-            all_sub_mask_1d_indexes_for_pixelization_1d_index=all_sub_mask_1d_indexes_for_pixelization_1d_index,
+            slim_index_for_sub_slim_index=slim_index_for_sub_slim_index,
+            all_sub_slim_indexes_for_pixelization_index=all_sub_slim_indexes_for_pixelization_index,
         )
 
         assert (pixelization_normalized_residuals == np.array([0.0, 1.0, 1.0])).all()
@@ -331,19 +307,15 @@ class TestPixelizationChiSquareds:
         pixelization_values = np.ones(3)
         reconstructed_data_1d = np.ones(9)
         noise_map_1d = np.ones(9)
-        mask_1d_index_for_sub_mask_1d_index = np.array([0, 1, 2, 3, 4, 5, 6, 7, 8])
-        all_sub_mask_1d_indexes_for_pixelization_1d_index = [
-            [0, 0, 0],
-            [1, 1, 1],
-            [2, 2, 2],
-        ]
+        slim_index_for_sub_slim_index = np.array([0, 1, 2, 3, 4, 5, 6, 7, 8])
+        all_sub_slim_indexes_for_pixelization_index = [[0, 0, 0], [1, 1, 1], [2, 2, 2]]
 
         pixelization_chi_squareds = aa.util.inversion.inversion_chi_squared_map_from(
             pixelization_values=pixelization_values,
             data=reconstructed_data_1d,
             noise_map_1d=noise_map_1d,
-            mask_1d_index_for_sub_mask_1d_index=mask_1d_index_for_sub_mask_1d_index,
-            all_sub_mask_1d_indexes_for_pixelization_1d_index=all_sub_mask_1d_indexes_for_pixelization_1d_index,
+            slim_index_for_sub_slim_index=slim_index_for_sub_slim_index,
+            all_sub_slim_indexes_for_pixelization_index=all_sub_slim_indexes_for_pixelization_index,
         )
 
         assert (pixelization_chi_squareds == np.zeros(3)).all()
@@ -353,19 +325,15 @@ class TestPixelizationChiSquareds:
         pixelization_values = np.ones(3)
         reconstructed_data_1d = 2.0 * np.ones(9)
         noise_map_1d = 2.0 * np.ones(9)
-        mask_1d_index_for_sub_mask_1d_index = np.array([0, 1, 2, 3, 4, 5, 6, 7, 8])
-        all_sub_mask_1d_indexes_for_pixelization_1d_index = [
-            [0, 1, 2],
-            [3, 4, 5],
-            [6, 7, 8],
-        ]
+        slim_index_for_sub_slim_index = np.array([0, 1, 2, 3, 4, 5, 6, 7, 8])
+        all_sub_slim_indexes_for_pixelization_index = [[0, 1, 2], [3, 4, 5], [6, 7, 8]]
 
         pixelization_chi_squareds = aa.util.inversion.inversion_chi_squared_map_from(
             pixelization_values=pixelization_values,
             data=reconstructed_data_1d,
             noise_map_1d=noise_map_1d,
-            mask_1d_index_for_sub_mask_1d_index=mask_1d_index_for_sub_mask_1d_index,
-            all_sub_mask_1d_indexes_for_pixelization_1d_index=all_sub_mask_1d_indexes_for_pixelization_1d_index,
+            slim_index_for_sub_slim_index=slim_index_for_sub_slim_index,
+            all_sub_slim_indexes_for_pixelization_index=all_sub_slim_indexes_for_pixelization_index,
         )
 
         assert (pixelization_chi_squareds == 0.25 * np.ones(3)).all()
@@ -373,19 +341,15 @@ class TestPixelizationChiSquareds:
         pixelization_values = np.ones(3)
         reconstructed_data_1d = np.array([1.0, 1.0, 1.0, 2.0, 2.0, 2.0, 3.0, 3.0, 3.0])
         noise_map_1d = np.array([0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 4.0, 4.0, 4.0])
-        mask_1d_index_for_sub_mask_1d_index = np.array([0, 1, 2, 3, 4, 5, 6, 7, 8])
-        all_sub_mask_1d_indexes_for_pixelization_1d_index = [
-            [0, 1, 2],
-            [3, 4, 5],
-            [6, 7, 8],
-        ]
+        slim_index_for_sub_slim_index = np.array([0, 1, 2, 3, 4, 5, 6, 7, 8])
+        all_sub_slim_indexes_for_pixelization_index = [[0, 1, 2], [3, 4, 5], [6, 7, 8]]
 
         pixelization_chi_squareds = aa.util.inversion.inversion_chi_squared_map_from(
             pixelization_values=pixelization_values,
             data=reconstructed_data_1d,
             noise_map_1d=noise_map_1d,
-            mask_1d_index_for_sub_mask_1d_index=mask_1d_index_for_sub_mask_1d_index,
-            all_sub_mask_1d_indexes_for_pixelization_1d_index=all_sub_mask_1d_indexes_for_pixelization_1d_index,
+            slim_index_for_sub_slim_index=slim_index_for_sub_slim_index,
+            all_sub_slim_indexes_for_pixelization_index=all_sub_slim_indexes_for_pixelization_index,
         )
 
         assert (pixelization_chi_squareds == np.array([0.0, 4.0, 0.25])).all()
